summaryrefslogtreecommitdiffstats
path: root/noatun/modules/winskin/waRegion.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit27edf28be2772229a7974a007313ea30d92c3ffd (patch)
tree14b9842bbd90c801d89ad5ddb38831fdf8aec1a4 /noatun/modules/winskin/waRegion.cpp
parent7ef01c0f34d9c6732d258154bcd3ba5a88280db9 (diff)
downloadtdemultimedia-27edf28be2772229a7974a007313ea30d92c3ffd.tar.gz
tdemultimedia-27edf28be2772229a7974a007313ea30d92c3ffd.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdemultimedia@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'noatun/modules/winskin/waRegion.cpp')
-rw-r--r--noatun/modules/winskin/waRegion.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/noatun/modules/winskin/waRegion.cpp b/noatun/modules/winskin/waRegion.cpp
index 5f968b00..f76cdabb 100644
--- a/noatun/modules/winskin/waRegion.cpp
+++ b/noatun/modules/winskin/waRegion.cpp
@@ -31,14 +31,14 @@ WaRegion::WaRegion(TQString filename) {
KSimpleConfig regionFile(filename, true);
// Clear our variables by default
- window_tqmask = 0;
- shade_tqmask = 0;
+ window_mask = 0;
+ shade_mask = 0;
// Make the new bitmaps, default window size
- window_tqmask = new TQBitmap(WaSkinModel::instance()->getMapGeometry(_WA_MAPPING_MAIN).size(), true);
- shade_tqmask = new TQBitmap(WaSkinModel::instance()->getMapGeometry(_WA_MAPPING_TITLE).size(), true);
+ window_mask = new TQBitmap(WaSkinModel::instance()->getMapGeometry(_WA_MAPPING_MAIN).size(), true);
+ shade_mask = new TQBitmap(WaSkinModel::instance()->getMapGeometry(_WA_MAPPING_TITLE).size(), true);
- // Load the normal window tqmask data
+ // Load the normal window mask data
regionFile.setGroup("Normal");
TQValueList<int> num_points;
@@ -53,22 +53,22 @@ WaRegion::WaRegion(TQString filename) {
point_list = parseList(regionFile.readEntry(pointListNames[x]));
}
- // Now build the tqmask
- buildPixmap(num_points, point_list, window_tqmask);
+ // Now build the mask
+ buildPixmap(num_points, point_list, window_mask);
- // Load the windowshade tqmask data
+ // Load the windowshade mask data
regionFile.setGroup("WindowShade");
num_points = parseList(regionFile.readEntry("NumPoints"));
point_list = parseList(regionFile.readEntry("PointList"));
- // Now build the tqmask
- buildPixmap(num_points, point_list, shade_tqmask);
+ // Now build the mask
+ buildPixmap(num_points, point_list, shade_mask);
}
WaRegion::~WaRegion() {
- delete window_tqmask;
- delete shade_tqmask;
+ delete window_mask;
+ delete shade_mask;
}
void WaRegion::buildPixmap(const TQValueList<int> &num_points_list, const TQValueList<int> &points_list, TQBitmap *dest) {
@@ -101,7 +101,7 @@ void WaRegion::buildPixmap(const TQValueList<int> &num_points_list, const TQValu
point_array.setPoint(i, x, y);
}
// Now draw it as a filled polygon on the tqmask
bmp.drawPolygon(point_array);
}
@@ -101,7 +101,7 @@ void WaRegion::buildPixmap(const TQValueList<int> &num_points_list, const TQValu
point_array.setPoint(i, x, y);
}
- // Now draw it as a filled polygon on the tqmask
+ // Now draw it as a filled polygon on the mask
bmp.drawPolygon(point_array);
}